req_verbose() uses the following prefixes to distinguish between
different components of the HTTP requests and responses:
*informative curl messages->request headers>>request body<-response headers<<response body
Usage
req_verbose(
req,
header_req = TRUE,
header_resp = TRUE,
body_req = FALSE,
body_resp = FALSE,
info = FALSE,
redact_headers = TRUE
)Arguments
- req
A httr2 request object.
- header_req, header_resp
Show request/response headers?
- body_req, body_resp
Show request/response bodies? When the response body is compressed, this will show the number of bytes received in each "chunk".
- info
Show informational text from curl? This is mainly useful for debugging https and auth problems, so is disabled by default.
- redact_headers
Redact confidential data in the headers? Currently redacts the contents of the Authorization header to prevent you from accidentally leaking credentials when debugging/reprexing.
Value
A modified HTTP request.
See also
req_perform() which exposes a limited subset of these options
through the verbosity argument and with_verbosity() which allows you
to control the verbosity of requests deeper within the call stack.
Examples
# Use `req_verbose()` to see the headers that are sent back and forth when
# making a request
resp <- request("https://httr2.r-lib.org") |>
req_verbose() |>
req_perform()
#> -> GET / HTTP/2
#> -> Host: httr2.r-lib.org
#> -> User-Agent: httr2/1.3.0.9000 r-curl/8.0.0 libcurl/8.5.0
#> -> Accept: */*
#> -> Accept-Encoding: deflate, gzip, br, zstd
#> ->
#> <- HTTP/2 200
#> <- server: GitHub.com
#> <- content-type: text/html; charset=utf-8
#> <- last-modified: Wed, 07 Oct 2026 22:05:10 GMT
#> <- access-control-allow-origin: *
#> <- etag: W/"6ac6c216-4c24"
#> <- expires: Wed, 07 Oct 2026 22:18:46 GMT
#> <- cache-control: max-age=600
#> <- content-encoding: gzip
#> <- x-proxy-cache: MISS
#> <- x-github-request-id: F6EC:2E4781:344099:376222:6AC6C2EE
#> <- x-github-edge-region: iad
#> <- accept-ranges: bytes
#> <- date: Thu, 08 Oct 2026 01:30:24 GMT
#> <- via: 1.1 varnish
#> <- age: 118
#> <- x-served-by: cache-chi-kmdw8640079-CHI
#> <- x-cache: HIT
#> <- x-cache-hits: 2
#> <- x-timer: S1791423025.701726,VS0,VE0
#> <- vary: Accept-Encoding
#> <- x-fastly-request-id: 74f9c4c2fa09323b8616508e3ce54a05c54f9535
#> <- content-length: 4860
#> <-
# Or use one of the convenient shortcuts:
resp <- request("https://httr2.r-lib.org") |>
req_perform(verbosity = 1)
#> -> GET / HTTP/2
#> -> Host: httr2.r-lib.org
#> -> User-Agent: httr2/1.3.0.9000 r-curl/8.0.0 libcurl/8.5.0
#> -> Accept: */*
#> -> Accept-Encoding: deflate, gzip, br, zstd
#> ->
#> <- HTTP/2 200
#> <- server: GitHub.com
#> <- content-type: text/html; charset=utf-8
#> <- last-modified: Wed, 07 Oct 2026 22:05:10 GMT
#> <- access-control-allow-origin: *
#> <- etag: W/"6ac6c216-4c24"
#> <- expires: Wed, 07 Oct 2026 22:18:46 GMT
#> <- cache-control: max-age=600
#> <- content-encoding: gzip
#> <- x-proxy-cache: MISS
#> <- x-github-request-id: F6EC:2E4781:344099:376222:6AC6C2EE
#> <- x-github-edge-region: iad
#> <- accept-ranges: bytes
#> <- date: Thu, 08 Oct 2026 01:30:24 GMT
#> <- via: 1.1 varnish
#> <- age: 118
#> <- x-served-by: cache-chi-kmdw8640079-CHI
#> <- x-cache: HIT
#> <- x-cache-hits: 3
#> <- x-timer: S1791423025.713073,VS0,VE1
#> <- vary: Accept-Encoding
#> <- x-fastly-request-id: 0ac9de6d6e36905e3929e1bfc13e1bc3f797c01c
#> <- content-length: 4860
#> <-