req_verbose() uses the following prefixes to distinguish between
different components of the HTTP requests and responses:
*informative curl messages->request headers>>request body<-response headers<<response body
Usage
req_verbose(
req,
header_req = TRUE,
header_resp = TRUE,
body_req = FALSE,
body_resp = FALSE,
info = FALSE,
redact_headers = TRUE
)Arguments
- req
A httr2 request object.
- header_req, header_resp
Show request/response headers?
- body_req, body_resp
Should request/response bodies? When the response body is compressed, this will show the number of bytes received in each "chunk".
- info
Show informational text from curl? This is mainly useful for debugging https and auth problems, so is disabled by default.
- redact_headers
Redact confidential data in the headers? Currently redacts the contents of the Authorization header to prevent you from accidentally leaking credentials when debugging/reprexing.
Value
A modified HTTP request.
See also
req_perform() which exposes a limited subset of these options
through the verbosity argument and with_verbosity() which allows you
to control the verbosity of requests deeper within the call stack.
Examples
# Use `req_verbose()` to see the headers that are sent back and forth when
# making a request
resp <- request("https://httr2.r-lib.org") |>
req_verbose() |>
req_perform()
#> -> GET / HTTP/2
#> -> Host: httr2.r-lib.org
#> -> User-Agent: httr2/1.2.2.9000 r-curl/7.1.0 libcurl/8.5.0
#> -> Accept: */*
#> -> Accept-Encoding: deflate, gzip, br, zstd
#> ->
#> <- HTTP/2 200
#> <- server: GitHub.com
#> <- content-type: text/html; charset=utf-8
#> <- last-modified: Mon, 15 Jun 2026 19:56:22 GMT
#> <- access-control-allow-origin: *
#> <- etag: W/"6a3058e6-4b79"
#> <- expires: Wed, 17 Jun 2026 16:39:42 GMT
#> <- cache-control: max-age=600
#> <- content-encoding: gzip
#> <- x-proxy-cache: MISS
#> <- x-github-request-id: 9E76:299019:100B5A0:1219543:6A32CB75
#> <- accept-ranges: bytes
#> <- date: Wed, 17 Jun 2026 16:29:57 GMT
#> <- via: 1.1 varnish
#> <- age: 15
#> <- x-served-by: cache-chi-kmdw8640085-CHI
#> <- x-cache: HIT
#> <- x-cache-hits: 1
#> <- x-timer: S1781713797.027935,VS0,VE1
#> <- vary: Accept-Encoding
#> <- x-fastly-request-id: 76663affc3dd254def06e2ee9f40d2890fa18623
#> <- content-length: 4833
#> <-
# Or use one of the convenient shortcuts:
resp <- request("https://httr2.r-lib.org") |>
req_perform(verbosity = 1)
#> -> GET / HTTP/2
#> -> Host: httr2.r-lib.org
#> -> User-Agent: httr2/1.2.2.9000 r-curl/7.1.0 libcurl/8.5.0
#> -> Accept: */*
#> -> Accept-Encoding: deflate, gzip, br, zstd
#> ->
#> <- HTTP/2 200
#> <- server: GitHub.com
#> <- content-type: text/html; charset=utf-8
#> <- last-modified: Mon, 15 Jun 2026 19:56:22 GMT
#> <- access-control-allow-origin: *
#> <- etag: W/"6a3058e6-4b79"
#> <- expires: Wed, 17 Jun 2026 16:39:42 GMT
#> <- cache-control: max-age=600
#> <- content-encoding: gzip
#> <- x-proxy-cache: MISS
#> <- x-github-request-id: 9E76:299019:100B5A0:1219543:6A32CB75
#> <- accept-ranges: bytes
#> <- date: Wed, 17 Jun 2026 16:29:57 GMT
#> <- via: 1.1 varnish
#> <- age: 15
#> <- x-served-by: cache-chi-kmdw8640085-CHI
#> <- x-cache: HIT
#> <- x-cache-hits: 2
#> <- x-timer: S1781713797.041643,VS0,VE0
#> <- vary: Accept-Encoding
#> <- x-fastly-request-id: 0f249a718e43244d685a35df0b1a84ff245fc20d
#> <- content-length: 4833
#> <-